@@ -23,9 +23,9 @@ class Connection(object):
         self.reset_values()
 
         options = options or {}
-        self.options = {
-            key: value for key, value in options.iteritems() if value is not None
-        }
+        self.options = dict(
+            (key, value) for key, value in options.iteritems() if value is not None
+        )
 
         self.options.setdefault('port', 5433)
         self.options.setdefault('read_timeout', 600)
@@ -186,13 +186,15 @@ class Connection(object):
             self.parameters[message.name] = message.value
         elif isinstance(message, messages.ReadyForQuery):
             self.transaction_status = message.transaction_status
+        elif isinstance(message, messages.CommandComplete):
+            pass
         else:
             raise errors.MessageError("Unhandled message: {0}".format(message))
 
     def __str__(self):
-        safe_options = {
-            key: value for key, value in self.options.iteritems() if key != 'password'
-        }
+        safe_options = dict(
+            (key, value) for key, value in self.options.iteritems() if key != 'password'
+        )
         s1 = "<Vertica.Connection:{0} parameters={1} backend_pid={2}, ".format(
             id(self), self.parameters, self.backend_pid
         )
